# z/OS Edit

This GUI application provides a way to edit datasets on z/OS. It is a simple text editor that allows you to open, edit, and save files on z/OS.

## Installation

`pip install zosedit`

## Usage

To run the application, simply type `zosedit` in your terminal.

